==> jabber-transport-0.7pre4.tar.gz: jabber-transport-0.7pre4/services/basic/conn.c <==
#include "svc_basic.h"

void svc_basic_onSend(thread t, jpacket p)
{
    session s = (session)(t->data);
    thread t_socket = (thread)(s->send_evt_data);
    xmlnode from;

    xmlnode_hide_attrib(p->x, "to");
    if(p->from != NULL && jid_cmp(p->from,s->id) != 0)
    {
        xmlnode_put_attrib(p->x, "from", jid_full(p->from));
    }

    debug("SVC_BASIC: got a packet[%s] to send to the user[%d]",xmlnode2str(p->x),t_socket);

    xmlstream_write(t_socket, p->x);
}

/* the connection/stream has passed all the test by the server when it get's here */
void svc_basic_onNode(thread t, xmlnode in, int type)
{
    tstream ts = (tstream)(t->data);
    char *server = (char *)(ts->data_aux5);
    xmlnode query;
    jpacket p;
    session s;

    printf("jserver basic XML NODE: %d type[%d] [%d]'%s'\n",ts->fd,type,in,xmlnode2str(in));
 
    s = svc_basic_lookup(CMD_CHECK, t, NULL);
    
    if(type == XMLSTREAM_ROOT)
    {
        pth_cleanup_push(svc_basic_cleanup,(void *)t);
        xmlstream_write_header(t, xmlstream_header(NS_CLIENT,NULL,xmlnode_get_attrib(in, "to")));
        server = pstrdup(t->p,xmlnode_get_attrib(in, "to"));
        ts->data_aux5 = (void *)server;
        return;
    }

    if(type == XMLSTREAM_CLOSE)
    {
        /* the connection was closed */
        printf("connection closed\n");
        return;
    }

    if(type == XMLSTREAM_ERROR)
    {
        /* the connection was closed */
        printf("XML error, connection closed\n");
        xmlstream_error(t, "Invalid XML Received");
        return;
    }

    p = jpacket_new(xmlnode_dup(in));

    /* check the iq's that we handle as a service from the client before they have a session */
    if(s == NULL && j_strcmp(xmlnode_get_name(p->x), "iq") == 0)
    {
        p->from = jid_new(p->p, server); /* kludge the server name they used to connect to pass to the session */
        query = xmlnode_get_tag(p->x, "query");
        if(j_strcmp(xmlnode_get_attrib(query,"xmlns"),"jabber:iq:auth") == 0 && s == NULL)
        {
            svc_basic_auth(t, p, query);
            xmlstream_write(t,p->x);
            return;
        }
    }

    if(s != NULL)
    {
        debug("sending packet to session");
        psend(s->mp_from, p);
    }else{
        debug("no session found for this connection, dropping data");
        xmlnode_free(p->x);
    }
}


void svc_basic_cleanup(void *arg)
{
    thread t = (thread)arg;
    tstream ts = (tstream)(t->data);

    debug("SVC_BASIC: cleanup");
    session_end(svc_basic_lookup(CMD_CHECK,t,NULL));
    svc_basic_lookup(CMD_DEL,t,NULL);
}

==> jabber-transport-0.8.tar.gz: jabber-transport-0.8/services/basic/conn.c <==
#include "svc_basic.h"

void svc_basic_onSend(thread t, jpacket p)
{
    session s = (session)(t->data);
    thread t_socket = (thread)(s->send_evt_data);

    if(p == NULL)
    { /* signal to exit from the session */
        if(svc_basic_lookup(CMD_CHECK,t_socket,NULL) != NULL)
        {
            jdebug(ZONE,"session exited externally");
            xmlstream_error(t_socket,"forced disconnect");
            svc_basic_lookup(CMD_DEL,t_socket,NULL);
        }
        return;
    }

    xmlnode_hide_attrib(p->x, "to");
    if(p->from != NULL && jid_cmp(p->from,s->id) != 0)
    {
        xmlnode_put_attrib(p->x, "from", jid_full(p->from));
    }

    jdebug(ZONE,"SVC_BASIC: got a packet[%s] to send to the user[%d]",xmlnode2str(p->x),t_socket);

    xmlstream_write(t_socket, p->x);
}

/* the connection/stream has passed all the test by the server when it get's here */
void svc_basic_onNode(thread t, xmlnode in, int type)
{
    tstream ts = (tstream)(t->data);
    char *server = (char *)(ts->data_aux5);
    xmlnode query;
    jpacket p;
    session s;

    s = svc_basic_lookup(CMD_CHECK, t, NULL);
    
    if(type == XMLSTREAM_ROOT)
    {
        pth_cleanup_push(svc_basic_cleanup,(void *)t);
        xmlstream_write_header(t, xmlstream_header(NS_CLIENT,NULL,xmlnode_get_attrib(in, "to")));
        server = pstrdup(t->p,xmlnode_get_attrib(in, "to"));
        ts->data_aux5 = (void *)server;
        return;
    }

    if(type == XMLSTREAM_CLOSE)
    {
        /* the connection was closed */
        return;
    }

    if(type == XMLSTREAM_BOUNCE)
    {
        /* leftovers that didn't get sent */
        jdebug(ZONE,"leftovers: %s",xmlnode2str(in));
        return;
    }

    if(type == XMLSTREAM_ERROR)
    {
        /* the connection was closed */
        xmlstream_error(t, "Invalid XML Received");
        return;
    }

    p = jpacket_new(xmlnode_dup(in));

    /* check the iq's that we handle as a service from the client before they have a session */
    if(s == NULL && j_strcmp(xmlnode_get_name(p->x), "iq") == 0)
    {
        p->from = jid_new(p->p, server); /* kludge the server name they used to connect to pass to the session */
        query = xmlnode_get_tag(p->x, "query");
        if(j_strcmp(xmlnode_get_attrib(query,"xmlns"),"jabber:iq:auth") == 0)
        {
            svc_basic_auth(t, p, query);
            xmlstream_write(t,p->x);
            return;
        }
        if(j_strcmp(xmlnode_get_attrib(query,"xmlns"),"jabber:iq:register") == 0)
        {
            svc_basic_register(server,p);
            xmlstream_write(t,p->x);
            return;
        }
    }

    if(s != NULL)
    {
        jdebug(ZONE,"sending packet to session: %s",xmlnode2str(p->x));
        psend(s->mp_from, p);
    }else{
        jdebug(ZONE,"no session found for this connection, bouncing");
        js_error(p->x,TERROR_INVALID,"No Session");
        xmlstream_write(t,p->x);
    }
}


void svc_basic_cleanup(void *arg)
{
    thread t = (thread)arg;
    session s;

    jdebug(ZONE,"SVC_BASIC: cleanup");
    s = svc_basic_lookup(CMD_CHECK,t,NULL);
    if(s != NULL)
    {
        svc_basic_lookup(CMD_DEL,t,NULL);
        session_end(s,"disconnected");
    }
}
